/***************************************************************
 * Name:      scroll.cpp
 * Purpose:   Code for Dialog scroll
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-30
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "scroll.h"

IMPLEMENT_DYNAMIC_CLASS( sbValidator, wxValidator )
BEGIN_EVENT_TABLE( sbValidator, wxValidator )
END_EVENT_TABLE()

bool sbValidator::TransferFromWindow()
{
    try {
        wxScrollBar *sb = dynamic_cast<wxScrollBar*>(m_validatorWindow);
        *m_valor = sb->GetThumbPosition();
    }
    catch (...) {
        wxFAIL_MSG( _T("sbValidator sólo funciona con wxScrollBar"));
        return false;
    }
    return true;
}

bool sbValidator::TransferToWindow()
{
    try {
        wxScrollBar *sb = dynamic_cast<wxScrollBar*>(m_validatorWindow);
        sb->SetThumbPosition(*m_valor);
    }
    catch (...) {
        wxFAIL_MSG( _T("sbValidator sólo funciona con wxScrollBar"));
        return false;
    }
    return true;
}

wxBEGIN_EVENT_TABLE(scroll, wxDialog)
    EVT_CLOSE(scroll::OnClose)
    EVT_COMMAND_SCROLL(idHorizontal, scroll::OnScrollH)
    EVT_COMMAND_SCROLL(idVertical, scroll::OnScrollV)
wxEND_EVENT_TABLE()

scroll::scroll(wxWindow *wnd, datosScroll &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de scroll")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    wxString cad;

    SetBackgroundColour(wxColour(200, 200, 240));

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_horizontal = new wxScrollBar(this, idHorizontal, wxPoint(20,0), wxSize(200, wxDefaultCoord), wxSB_HORIZONTAL, sbValidator(&datos.horizontal));
    boxHorizontal->Add(m_horizontal, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_vertical = new wxScrollBar(this, idVertical, wxPoint(0,20), wxSize(wxDefaultCoord, 200), wxSB_VERTICAL, sbValidator(&datos.vertical));
    boxHorizontal->Add(m_vertical, wxSizerFlags().Border());

    cad << data.horizontal;
    m_textHorizontal = new wxStaticText(this, idTextHorizontal, cad, wxDefaultPosition, wxDefaultSize, wxBORDER_SUNKEN);
    boxHorizontal->Add(m_textHorizontal, wxSizerFlags().Border());

    cad.clear();
    cad << data.vertical;
    m_textVertical = new wxStaticText(this, idTextVertical, cad, wxDefaultPosition, wxDefaultSize, wxBORDER_SUNKEN);
    boxHorizontal->Add(m_textVertical, wxSizerFlags().Border());

    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Left());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);

    m_horizontal->SetRange(data.hrango);
    m_horizontal->SetPageSize(10);

    m_vertical->SetRange(data.vrango);
    m_vertical->SetPageSize(6);
}

scroll::~scroll()
{
    //dtor
}

void scroll::OnClose(wxCloseEvent& event) {
    Destroy();
}

void scroll::OnScrollH(wxScrollEvent& event) {
    wxString cad;
    cad << event.GetPosition();
    m_textHorizontal->SetLabel(cad);
}

void scroll::OnScrollV(wxScrollEvent& event) {
    wxString cad;
    cad << event.GetPosition();
    m_textVertical->SetLabel(cad);
}
